@@ -4,6 +4,7 @@ from datetime import timedelta
 from pyramid import testing
 from pyramid_beaker import set_cache_regions_from_settings
 
+from cms import locale_negotiator_with_fallbacks
 from cms.tests.base import UnicoreTestCase
 from cms.views.cms_views import CmsViews
 
@@ -53,6 +54,7 @@ class TestViews(UnicoreTestCase):
         }
         self.config = testing.setUp(settings=settings)
         set_cache_regions_from_settings(settings)
+        self.config.set_locale_negotiator(locale_negotiator_with_fallbacks)
         self.views = CmsViews(testing.DummyRequest())
 
     def tearDown(self):
